@@ -91,6 +91,7 @@ class NonDXLStatusThread(threading.Thread):
             self.stats.mark_loop_end()
             if not self.shutdown_flag.is_set():
                 time.sleep(self.stats.get_loop_sleep_time())
+            self.titr=self.titr+1
         self.robot.logger.debug('Shutting down NonDXLStatusThread')
 
 
@@ -223,7 +224,16 @@ class Robot(Device):
             self.lift.push_command()
             self.pimu.push_command()
             self.wacc.push_command()
-            self.pimu.trigger_motor_sync()
+
+            #Check if need to do a motor sync by looking at if there's been a pimu sync signal sent
+            #since the last stepper.set_command for each joint
+            do_sync=(self.pimu.ts_last_motor_sync is not None) and (
+                    self.arm.motor.ts_last_syncd_motion>self.pimu.ts_last_motor_sync
+                    or self.lift.motor.ts_last_syncd_motion>self.pimu.ts_last_motor_sync
+                    or self.base.right_wheel.ts_last_syncd_motion>self.pimu.ts_last_motor_sync
+                    or self.base.left_wheel.ts_last_syncd_motion>self.pimu.ts_last_motor_sync)
+            if  self.pimu.ts_last_motor_sync is None or do_sync:
+                self.pimu.trigger_motor_sync()
 
     # ######### Waypoint Trajectory Interface ##############################
 
